#Topsis Package
This package is a Python library that implements the TOPSIS method on a given dataset, allowing for identification of the best and worst decisions based on criteria and attributes. It can be easily used by calling appropriate functions on the dataset through the command line. This package offers a convenient and efficient way to make data-driven decisions.##Usage
Following query on terminal will provide you the best and worst decisions for the dataset.
